@@ -20,7 +20,7 @@
 #define MT_GTK_CLIENT_GUI_CONFIG_H
 
 #include <gtk/gtk.h>
-#include <libmt_client.h>
+#include <mt_client.h>
 
 extern GString *configfilename;
 
